@@ -20,19 +20,19 @@ class TestModlist(unittest.TestCase):
     addModlist_tests = [
         (
             {
-                'objectClass':['person','pilotPerson'],
-                'cn':['Michael Str\303\266der','Michael Stroeder'],
-                'sn':['Str\303\266der'],
+                'objectClass': [b'person',b'pilotPerson'],
+                'cn':[b'Michael Str\303\266der',b'Michael Stroeder'],
+                'sn':[b'Str\303\266der'],
                 'dummy1':[],
-                'dummy2':['2'],
-                'dummy3':[''],
+                'dummy2':[b'2'],
+                'dummy3':[b''],
             },
             [
-                ('objectClass',['person','pilotPerson']),
-                ('cn',['Michael Str\303\266der','Michael Stroeder']),
-                ('sn',['Str\303\266der']),
-                ('dummy2',['2']),
-                ('dummy3',['']),
+                ('objectClass',[b'person',b'pilotPerson']),
+                ('cn',[b'Michael Str\303\266der',b'Michael Stroeder']),
+                ('sn',[b'Str\303\266der']),
+                ('dummy2',[b'2']),
+                ('dummy3',[b'']),
             ]
         ),
     ]
@@ -52,42 +52,42 @@ class TestModlist(unittest.TestCase):
     modifyModlist_tests = [
         (
             {
-                'objectClass':['person','pilotPerson'],
-                'cn':['Michael Str\303\266der','Michael Stroeder'],
-                'sn':['Str\303\266der'],
-                'enum':['a','b','c'],
-                'c':['DE'],
+                'objectClass':[b'person',b'pilotPerson'],
+                'cn':[b'Michael Str\303\266der',b'Michael Stroeder'],
+                'sn':[b'Str\303\266der'],
+                'enum':[b'a',b'b',b'c'],
+                'c':[b'DE'],
             },
             {
-                'objectClass':['person','inetOrgPerson'],
-                'cn':['Michael Str\303\266der','Michael Stroeder'],
+                'objectClass':[b'person',b'inetOrgPerson'],
+                'cn':[b'Michael Str\303\266der',b'Michael Stroeder'],
                 'sn':[],
-                'enum':['a','b','d'],
-                'mail':['michael@stroeder.com'],
+                'enum':[b'a',b'b',b'd'],
+                'mail':[b'michael@stroeder.com'],
             },
             [],
             [
                 (ldap.MOD_DELETE,'objectClass',None),
-                (ldap.MOD_ADD,'objectClass',['person','inetOrgPerson']),
+                (ldap.MOD_ADD,'objectClass',[b'person',b'inetOrgPerson']),
                 (ldap.MOD_DELETE,'c',None),
                 (ldap.MOD_DELETE,'sn',None),
-                (ldap.MOD_ADD,'mail',['michael@stroeder.com']),
+                (ldap.MOD_ADD,'mail',[b'michael@stroeder.com']),
                 (ldap.MOD_DELETE,'enum',None),
-                (ldap.MOD_ADD,'enum',['a','b','d']),
+                (ldap.MOD_ADD,'enum',[b'a',b'b',b'd']),
             ]
         ),
 
         (
             {
-                'c':['DE'],
+                'c':[b'DE'],
             },
             {
-                'c':['FR'],
+                'c':[b'FR'],
             },
             [],
             [
                 (ldap.MOD_DELETE,'c',None),
-                (ldap.MOD_ADD,'c',['FR']),
+                (ldap.MOD_ADD,'c',[b'FR']),
             ]
         ),
 
@@ -95,10 +95,10 @@ class TestModlist(unittest.TestCase):
         # of removing an attribute with MOD_DELETE,attr_type,None
         (
             {
-                'objectClass':['person'],
+                'objectClass':[b'person'],
                 'cn':[None],
-                'sn':[''],
-                'c':['DE'],
+                'sn':[b''],
+                'c':[b'DE'],
             },
             {
                 'objectClass':[],
@@ -115,22 +115,22 @@ class TestModlist(unittest.TestCase):
 
         (
             {
-                'objectClass':['person'],
-                'cn':['Michael Str\303\266der','Michael Stroeder'],
-                'sn':['Str\303\266der'],
-                'enum':['a','b','C'],
+                'objectClass':[b'person'],
+                'cn':[b'Michael Str\303\266der',b'Michael Stroeder'],
+                'sn':[b'Str\303\266der'],
+                'enum':[b'a',b'b',b'C'],
             },
             {
-                'objectClass':['Person'],
-                'cn':['Michael Str\303\266der','Michael Stroeder'],
+                'objectClass':[b'Person'],
+                'cn':[b'Michael Str\303\266der',b'Michael Stroeder'],
                 'sn':[],
-                'enum':['a','b','c'],
+                'enum':[b'a',b'b',b'c'],
             },
             ['objectClass'],
             [
                 (ldap.MOD_DELETE,'sn',None),
                 (ldap.MOD_DELETE,'enum',None),
-                (ldap.MOD_ADD,'enum',['a','b','c']),
+                (ldap.MOD_ADD,'enum',[b'a',b'b',b'c']),
             ]
         ),
 
