@@ -646,6 +646,18 @@ class Test00_SimpleLDAPObject(SlapdTestCase):
             [self.server.suffix.encode('utf-8')]
         )
 
+    def test_compare_s_true(self):
+        base = self.server.suffix
+        l = self._ldap_conn
+        result = l.compare_s('cn=Foo1,%s' % base, 'cn', 'Foo1')
+        self.assertIs(result, True)
+
+    def test_compare_s_false(self):
+        base = self.server.suffix
+        l = self._ldap_conn
+        result = l.compare_s('cn=Foo1,%s' % base, 'cn', 'Foo2')
+        self.assertIs(result, False)
+
 
 class Test01_ReconnectLDAPObject(Test00_SimpleLDAPObject):
     """
@@ -690,7 +702,7 @@ class Test01_ReconnectLDAPObject(Test00_SimpleLDAPObject):
                 str('_retry_delay'): 60.0,
                 str('_retry_max'): 1,
                 str('_start_tls'): 0,
-                str('_trace_level'): 0,
+                str('_trace_level'): ldap._trace_level,
                 str('_trace_stack_limit'): 5,
                 str('_uri'): self.server.ldap_uri,
                 str('bytes_mode'): l1.bytes_mode,
